# EvenAge Environment Configuration

# Database
DATABASE_URL=postgresql://postgres:postgres@postgres:5432/evenage

# Message Broker
REDIS_URL=redis://redis:6379

# Object Storage
MINIO_ENDPOINT=minio:9000
MINIO_ACCESS_KEY=minioadmin
MINIO_SECRET_KEY=minioadmin123
MINIO_SECURE=false

# Observability
OTEL_EXPORTER_OTLP_ENDPOINT=http://jaeger:4318
PROMETHEUS_METRICS_PORT=8001

# API
API_HOST=0.0.0.0
API_PORT=8000

# Dashboard Authentication
EVENAGE_DASH_USERS=admin:admin

# LLM API Keys
GEMINI_API_KEY=your_gemini_api_key_here
OPENAI_API_KEY=your_openai_api_key_here
ANTHROPIC_API_KEY=your_anthropic_api_key_here
GROQ_API_KEY=your_groq_api_key_here

# Tool API Keys
SERPER_API_KEY=your_serper_api_key_here
