name: {{ pipeline_name }}
description: {{ description }}
tasks:
  - name: example_task
    description: Example task description
    agent: researcher
    expected_output: Expected output description
    tools: []
    async_execution: false
