fastapi>=0.112.0
uvicorn[standard]>=0.30.0
redis>=5.0.0
pyyaml>=6.0.0
requests>=2.31.0
beautifulsoup4>=4.12.0
google-generativeai>=0.3.0
SQLAlchemy>=2.0.0
pgvector>=0.2.5
psycopg2-binary>=2.9.9
prometheus-client>=0.20.0
opentelemetry-sdk>=1.26.0
opentelemetry-exporter-otlp>=1.26.0
